==> growthbook_sdk_flutter-3.3.0%2B0.tar.gz: test/common_test/gb_experiment_run_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:growthbook_sdk_flutter/growthbook_sdk_flutter.dart';

import '../Helper/gb_test_helper.dart';

void main() {
  group('GBExperimentRun Test', () {
    late final List evaluateCondition;
    setUpAll(() {
      evaluateCondition = GBTestHelper.getRunExperimentData();
    });

    test('Evaluate Feature', () {
      final failedScenarios = <String>[];
      final passedScenarios = <String>[];
      int failingIndex = 0;
      final listOfFailingIndex = <int>[];

      for (var item in evaluateCondition) {
        if (item is List) {
          final testContext = GBContextTest.fromMap(item[1]);
          final experiment = GBExperiment.fromJson(item[2]);

          final attr = testContext.attributes;

          final gbContext = GBContext(
            apiKey: '',
            hostURL: '',
            enabled: testContext.enabled,
            attributes: attr,
            forcedVariation: testContext.forcedVariations,
            qaMode: testContext.qaMode,
            trackingCallBack: (_, __) {},
            backgroundSync: false,
          );

          final result = GBExperimentEvaluator.evaluateExperiment(
              context: gbContext, experiment: experiment);
          final status = "${item[0]}\nExpected Result - ${item[3]} & ${item[4]}\nActual result - ${result.value} & ${result.inExperiment}\n\n";

          if (item[3].toString() == result.value.toString() &&
              item[4].toString() == result.inExperiment.toString() &&
              item[5].toString() == result.hashUsed.toString()) {
            passedScenarios.add(status);
          } else {
            failedScenarios.add(status);
            listOfFailingIndex.add(failingIndex);
          }
          failingIndex++;
        }
      }
      customLogger(
          'Passed Test ${passedScenarios.length} out of ${evaluateCondition.length}');
      expect(failedScenarios.length, 0);
    });
  });
}

==> growthbook_sdk_flutter-3.7.0%2B0.tar.gz: test/common_test/gb_experiment_run_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:growthbook_sdk_flutter/growthbook_sdk_flutter.dart';

import '../Helper/gb_test_helper.dart';

void main() {
  group('GBExperimentRun Test', () {
    late final List evaluateCondition;
    setUpAll(() {
      evaluateCondition = GBTestHelper.getRunExperimentData();
    });

    test('Evaluate Feature', () {
      final failedScenarios = <String>[];
      final passedScenarios = <String>[];
      int failingIndex = 0;
      final listOfFailingIndex = <int>[];

      for (var item in evaluateCondition) {
        if (item is List) {
          final testContext = GBContextTest.fromMap(item[1]);

          final experiment = GBExperiment.fromJson(item[2]);

          final attr = testContext.attributes;

          final gbContext = GBContext(
            apiKey: '',
            hostURL: '',
            enabled: testContext.enabled,
            attributes: attr,
            forcedVariation: testContext.forcedVariations,
            qaMode: testContext.qaMode,
            trackingCallBack: (_, __) {},
            backgroundSync: false,
            features: testContext.features,
          );

          final result = ExperimentEvaluator(attributeOverrides: {})
              .evaluateExperiment(gbContext, experiment);
          final status =
              "${item[0]}\nExpected Result - ${item[3]} & ${item[4]}\nActual result - ${result.value} & ${result.inExperiment}\n\n";

          if (item[3].toString() == result.value.toString() &&
              item[4] == result.inExperiment) {
            passedScenarios.add(status);
          } else {
            failedScenarios.add(status);
            listOfFailingIndex.add(failingIndex);
          }
          failingIndex++;
        }
      }
      customLogger(
          'Passed Test ${passedScenarios.length} out of ${evaluateCondition.length}');
      expect(failedScenarios.length, 0);
    });
  });
}
